exceptiontools.GraceContainerError
==================================

.. inheritance-diagram:: abjad.tools.exceptiontools.GraceContainerError.GraceContainerError
   :private-bases:

.. autoclass:: abjad.tools.exceptiontools.GraceContainerError.GraceContainerError

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.GraceContainerError.GraceContainerError.__delattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.GraceContainerError.GraceContainerError.__getitem__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.GraceContainerError.GraceContainerError.__getslice__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.GraceContainerError.GraceContainerError.__repr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.GraceContainerError.GraceContainerError.__setattr__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.GraceContainerError.GraceContainerError.__setstate__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.GraceContainerError.GraceContainerError.__str__

    Inherited from :py:class:`exceptions.BaseException`

.. automethod:: abjad.tools.exceptiontools.GraceContainerError.GraceContainerError.__unicode__

    Inherited from :py:class:`exceptions.BaseException`
